
## CATO-CLI - mutation.policy.antiMalwareFileHash.updateRule:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.policy.antiMalwareFileHash.updateRule) for documentation on this operation.

### Usage for mutation.policy.antiMalwareFileHash.updateRule:

`catocli mutation policy antiMalwareFileHash updateRule -h`

`catocli mutation policy antiMalwareFileHash updateRule <json>`

`catocli mutation policy antiMalwareFileHash updateRule "$(cat < mutation.policy.antiMalwareFileHash.updateRule.json)"`

`catocli mutation policy antiMalwareFileHash updateRule '{"antiMalwareFileHashPolicyMutationInput":{"policyMutationRevisionInput":{"id":"id"}},"antiMalwareFileHashUpdateRuleInput":{"antiMalwareFileHashUpdateRuleDataInput":{"action":"BLOCK","description":"string","enabled":true,"expirationDate":"example_value","fileName":"string","name":"string","sha256":"example_value"},"id":"id"}}'`


#### Operation Arguments for mutation.policy.antiMalwareFileHash.updateRule ####

`accountId` [ID] - (required) N/A    
`antiMalwareFileHashPolicyMutationInput` [AntiMalwareFileHashPolicyMutationInput] - (required) N/A    
`antiMalwareFileHashUpdateRuleInput` [AntiMalwareFileHashUpdateRuleInput] - (required) N/A    
